Cartel v0.1.1 Cartel View Source

The HTTP client for Elixir.

The Cartel module can be used to issue HTTP requests and parse HTTP responses to arbitrary urls.

iex> Cartel.get!("https://api.github.com")
%Cartel.Response{
  status_code: 200,
  headers: [{"content-type", "application/json"}],
  body: "{...}",
  request: %Cartel.Request{}
}

It’s very common to use Cartel in order to wrap APIs, which is when the Cartel.Base module shines. Visit the documentation for Cartel.Base for more information.

Under the hood, the Cartel module just uses Cartel.Base (as described in the documentation for Cartel.Base) without overriding any default function.

See request/1 for more details on how to issue HTTP requests

Link to this section Summary

Functions

Issues a DELETE request to the given url

Issues a DELETE request to the given url, raising an exception in case of failure

Issues a GET request to the given url

Issues a GET request to the given url, raising an exception in case of failure

Issues a HEAD request to the given url

Issues a HEAD request to the given url, raising an exception in case of failure

Issues an OPTIONS request to the given url

Issues a OPTIONS request to the given url, raising an exception in case of failure

Issues a PATCH request to the given url

Issues a PATCH request to the given url, raising an exception in case of failure

Issues a POST request to the given url

Issues a POST request to the given url, raising an exception in case of failure

Issues a PUT request to the given url, raising an exception in case of failure

Issues an HTTP request with the given method to the given url

Issues an HTTP request with the given method to the given url, raising an exception in case of failure

Starts Cartel and its dependencies

Requests the next message to be streamed for a given Cartel.AsyncResponse

Link to this section Types

Link to this section Functions

Link to this function delete(url, headers \\ [], params \\ %{}, options \\ []) View Source
delete(binary(), headers(), params(), keyword()) ::
  {:ok, Cartel.Response.t() | Cartel.AsyncResponse.t()}
  | {:error, Cartel.Error.t()}

Issues a DELETE request to the given url.

Returns {:ok, response} if the request is successful, {:error, reason} otherwise.

See request/1 for more detailed information.

Link to this function delete!(url, headers \\ [], params \\ %{}, options \\ []) View Source

Issues a DELETE request to the given url, raising an exception in case of failure.

If the request does not fail, the response is returned.

See request!/1 for more detailed information.

Link to this function get(url, headers \\ [], params \\ %{}, options \\ []) View Source
get(binary(), headers(), params(), keyword()) ::
  {:ok, Cartel.Response.t() | Cartel.AsyncResponse.t()}
  | {:error, Cartel.Error.t()}

Issues a GET request to the given url.

Returns {:ok, response} if the request is successful, {:error, reason} otherwise.

See request/1 for more detailed information.

Link to this function get!(url, headers \\ [], params \\ %{}, options \\ []) View Source

Issues a GET request to the given url, raising an exception in case of failure.

If the request does not fail, the response is returned.

See request!/1 for more detailed information.

Link to this function head(url, headers \\ [], params \\ %{}, options \\ []) View Source
head(binary(), headers(), params(), keyword()) ::
  {:ok, Cartel.Response.t() | Cartel.AsyncResponse.t()}
  | {:error, Cartel.Error.t()}

Issues a HEAD request to the given url.

Returns {:ok, response} if the request is successful, {:error, reason} otherwise.

See request/1 for more detailed information.

Link to this function head!(url, headers \\ [], params \\ %{}, options \\ []) View Source

Issues a HEAD request to the given url, raising an exception in case of failure.

If the request does not fail, the response is returned.

See request!/1 for more detailed information.

Link to this function options(url, headers \\ [], params \\ %{}, options \\ []) View Source
options(binary(), headers(), params(), keyword()) ::
  {:ok, Cartel.Response.t() | Cartel.AsyncResponse.t()}
  | {:error, Cartel.Error.t()}

Issues an OPTIONS request to the given url.

Returns {:ok, response} if the request is successful, {:error, reason} otherwise.

See request/1 for more detailed information.

Link to this function options!(url, headers \\ [], params \\ %{}, options \\ []) View Source
options!(binary(), headers(), params(), keyword()) ::
  {:ok, Cartel.Response.t() | Cartel.AsyncResponse.t()}
  | {:error, Cartel.Error.t()}

Issues a OPTIONS request to the given url, raising an exception in case of failure.

If the request does not fail, the response is returned.

See request!/1 for more detailed information.

Link to this function patch(url, body, headers \\ [], params \\ %{}, options \\ []) View Source
patch(binary(), any(), headers(), params(), keyword()) ::
  {:ok, Cartel.Response.t() | Cartel.AsyncResponse.t()}
  | {:error, Cartel.Error.t()}

Issues a PATCH request to the given url.

Returns {:ok, response} if the request is successful, {:error, reason} otherwise.

See request/1 for more detailed information.

Link to this function patch!(url, body, headers \\ [], params \\ %{}, options \\ []) View Source

Issues a PATCH request to the given url, raising an exception in case of failure.

If the request does not fail, the response is returned.

See request!/1 for more detailed information.

Link to this function post(url, body, headers \\ [], params \\ %{}, options \\ []) View Source
post(binary(), any(), headers(), params(), keyword()) ::
  {:ok, Cartel.Response.t() | Cartel.AsyncResponse.t()}
  | {:error, Cartel.Error.t()}

Issues a POST request to the given url.

Returns {:ok, response} if the request is successful, {:error, reason} otherwise.

See request/1 for more detailed information.

Link to this function post!(url, body, headers \\ [], params \\ %{}, options \\ []) View Source

Issues a POST request to the given url, raising an exception in case of failure.

If the request does not fail, the response is returned.

See request!/1 for more detailed information.

Link to this function process_request_body(request) View Source
process_request_body(Cartel.Request.t()) :: body()
Link to this function process_request_headers(request) View Source
process_request_headers(Cartel.Request.t()) :: headers()
Link to this function process_request_options(request) View Source
process_request_options(Cartel.Request.t()) :: keyword()
Link to this function process_request_params(request) View Source
process_request_params(Cartel.Request.t()) :: params()
Link to this function process_request_url(request) View Source
process_request_url(Cartel.Request.t()) :: String.t()
Link to this function process_response(response) View Source
process_response(Cartel.Response.t()) :: any()
Link to this function process_response_body(body) View Source
process_response_body(body()) :: any()
Link to this function process_response_chunk(chunk) View Source
process_response_chunk(any()) :: any()
Link to this function process_response_headers(headers) View Source
process_response_headers(headers()) :: any()
Link to this function process_response_status_code(status_code) View Source
process_response_status_code(integer()) :: any()
Link to this function put(url, body \\ "", headers \\ [], params \\ %{}, options \\ []) View Source
put(binary(), any(), headers(), params(), keyword()) ::
  {:ok, Cartel.Response.t() | Cartel.AsyncResponse.t()}
  | {:error, Cartel.Error.t()}

Issues a PUT request to the given url.

Returns {:ok, response} if the request is successful, {:error, reason} otherwise.

See request/1 for more detailed information.

Link to this function put!(url, body \\ "", headers \\ [], params \\ %{}, options \\ []) View Source

Issues a PUT request to the given url, raising an exception in case of failure.

If the request does not fail, the response is returned.

See request!/1 for more detailed information.

Issues an HTTP request with the given method to the given url.

This function is usually used indirectly by get/3, post/4, put/4, etc

Request keys:

  • method - HTTP method as an atom (:get, :head, :post, :put, :delete, etc.)
  • url - target url as a binary string or char list
  • headers - HTTP headers as an orddict (e.g., [{"Accept", "application/json"}])
  • body - request body. See more below
  • params - an enumerable consisting of two-item tuples that will be appended to the url as query string parameters
  • options - Keyword list of options

Request :body key:

  • binary, char list or an iolist
  • {:form, [{K, V}, ...]} - send a form url encoded
  • {:file, "/path/to/file"} - send a file
  • {:stream, enumerable} - lazily send a stream of binaries/charlists

Request :options key:

  • :timeout - timeout to establish a connection, in milliseconds. Default is 8000
  • :recv_timeout - timeout used when receiving a connection. Default is 5000
  • :stream_to - a PID to stream the response to
  • :async - if given :once, will only stream one message at a time, requires call to stream_next
  • :proxy - a proxy to be used for the request; it can be a regular url or a {Host, Port} tuple
  • :proxy_auth - proxy authentication {User, Password} tuple
  • :ssl - SSL options supported by the ssl erlang module
  • :follow_redirect - a boolean that causes redirects to be followed
  • :max_redirect - an integer denoting the maximum number of redirects to follow

Timeouts can be an integer or :infinity

This function returns {:ok, response} or {:ok, async_response} if the request is successful, {:error, reason} otherwise.

Examples

%Request{method: :post, url:"https://my.website.com", body: "{\"foo\": 3}", headers: [{"Accept", "application/json"}]}
|> request()

Issues an HTTP request with the given method to the given url, raising an exception in case of failure.

request!/1 works exactly like request/1 but it returns just the response in case of a successful request, raising an exception in case the request fails.

Starts Cartel and its dependencies.

Requests the next message to be streamed for a given Cartel.AsyncResponse.

See request!/1 for more detailed information.